@@ -357,7 +357,7 @@ class SSMClient:
             "OpsItem",
         ],
         ResourceId: str,
-        Tags: List[TagTypeDef],
+        Tags: List["TagTypeDef"],
     ) -> Dict[str, Any]:
         """
         [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.add_tags_to_resource)
@@ -387,7 +387,7 @@ class SSMClient:
         DefaultInstanceName: str = None,
         RegistrationLimit: int = None,
         ExpirationDate: datetime = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateActivationResultTypeDef:
         """
         [Client.create_activation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.create_activation)
@@ -399,9 +399,9 @@ class SSMClient:
         DocumentVersion: str = None,
         InstanceId: str = None,
         Parameters: Dict[str, List[str]] = None,
-        Targets: List[TargetTypeDef] = None,
+        Targets: List["TargetTypeDef"] = None,
         ScheduleExpression: str = None,
-        OutputLocation: InstanceAssociationOutputLocationTypeDef = None,
+        OutputLocation: "InstanceAssociationOutputLocationTypeDef" = None,
         AssociationName: str = None,
         AutomationTargetParameterName: str = None,
         MaxErrors: str = None,
@@ -415,7 +415,7 @@ class SSMClient:
         """
 
     def create_association_batch(
-        self, Entries: List[CreateAssociationBatchRequestEntryTypeDef]
+        self, Entries: List["CreateAssociationBatchRequestEntryTypeDef"]
     ) -> CreateAssociationBatchResultTypeDef:
         """
         [Client.create_association_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.create_association_batch)
@@ -425,7 +425,7 @@ class SSMClient:
         self,
         Content: str,
         Name: str,
-        Requires: List[DocumentRequiresTypeDef] = None,
+        Requires: List["DocumentRequiresTypeDef"] = None,
         Attachments: List[AttachmentsSourceTypeDef] = None,
         VersionName: str = None,
         DocumentType: Literal[
@@ -441,7 +441,7 @@ class SSMClient:
         ] = None,
         DocumentFormat: Literal["YAML", "JSON", "TEXT"] = None,
         TargetType: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateDocumentResultTypeDef:
         """
         [Client.create_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.create_document)
@@ -459,7 +459,7 @@ class SSMClient:
         EndDate: str = None,
         ScheduleTimezone: str = None,
         ClientToken: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateMaintenanceWindowResultTypeDef:
         """
         [Client.create_maintenance_window documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.create_maintenance_window)
@@ -470,11 +470,11 @@ class SSMClient:
         Description: str,
         Source: str,
         Title: str,
-        OperationalData: Dict[str, OpsItemDataValueTypeDef] = None,
-        Notifications: List[OpsItemNotificationTypeDef] = None,
+        OperationalData: Dict[str, "OpsItemDataValueTypeDef"] = None,
+        Notifications: List["OpsItemNotificationTypeDef"] = None,
         Priority: int = None,
-        RelatedOpsItems: List[RelatedOpsItemTypeDef] = None,
-        Tags: List[TagTypeDef] = None,
+        RelatedOpsItems: List["RelatedOpsItemTypeDef"] = None,
+        Tags: List["TagTypeDef"] = None,
         Category: str = None,
         Severity: str = None,
     ) -> CreateOpsItemResponseTypeDef:
@@ -496,8 +496,8 @@ class SSMClient:
             "ORACLE_LINUX",
             "DEBIAN",
         ] = None,
-        GlobalFilters: PatchFilterGroupTypeDef = None,
-        ApprovalRules: PatchRuleGroupTypeDef = None,
+        GlobalFilters: "PatchFilterGroupTypeDef" = None,
+        ApprovalRules: "PatchRuleGroupTypeDef" = None,
         ApprovedPatches: List[str] = None,
         ApprovedPatchesComplianceLevel: Literal[
             "CRITICAL", "HIGH", "MEDIUM", "LOW", "INFORMATIONAL", "UNSPECIFIED"
@@ -506,9 +506,9 @@ class SSMClient:
         RejectedPatches: List[str] = None,
         RejectedPatchesAction: Literal["ALLOW_AS_DEPENDENCY", "BLOCK"] = None,
         Description: str = None,
-        Sources: List[PatchSourceTypeDef] = None,
+        Sources: List["PatchSourceTypeDef"] = None,
         ClientToken: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreatePatchBaselineResultTypeDef:
         """
         [Client.create_patch_baseline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.create_patch_baseline)
@@ -517,7 +517,7 @@ class SSMClient:
     def create_resource_data_sync(
         self,
         SyncName: str,
-        S3Destination: ResourceDataSyncS3DestinationTypeDef = None,
+        S3Destination: "ResourceDataSyncS3DestinationTypeDef" = None,
         SyncType: str = None,
         SyncSource: ResourceDataSyncSourceTypeDef = None,
     ) -> Dict[str, Any]:
@@ -801,7 +801,7 @@ class SSMClient:
     def describe_maintenance_window_schedule(
         self,
         WindowId: str = None,
-        Targets: List[TargetTypeDef] = None,
+        Targets: List["TargetTypeDef"] = None,
         ResourceType: Literal["INSTANCE", "RESOURCE_GROUP"] = None,
         Filters: List[PatchOrchestratorFilterTypeDef] = None,
         MaxResults: int = None,
@@ -845,7 +845,7 @@ class SSMClient:
 
     def describe_maintenance_windows_for_target(
         self,
-        Targets: List[TargetTypeDef],
+        Targets: List["TargetTypeDef"],
         ResourceType: Literal["INSTANCE", "RESOURCE_GROUP"],
         MaxResults: int = None,
         NextToken: str = None,
@@ -1010,8 +1010,8 @@ class SSMClient:
 
     def get_inventory(
         self,
-        Filters: List[InventoryFilterTypeDef] = None,
-        Aggregators: List[InventoryAggregatorTypeDef] = None,
+        Filters: List["InventoryFilterTypeDef"] = None,
+        Aggregators: List["InventoryAggregatorTypeDef"] = None,
         ResultAttributes: List[ResultAttributeTypeDef] = None,
         NextToken: str = None,
         MaxResults: int = None,
@@ -1073,8 +1073,8 @@ class SSMClient:
     def get_ops_summary(
         self,
         SyncName: str = None,
-        Filters: List[OpsFilterTypeDef] = None,
-        Aggregators: List[OpsAggregatorTypeDef] = None,
+        Filters: List["OpsFilterTypeDef"] = None,
+        Aggregators: List["OpsAggregatorTypeDef"] = None,
         ResultAttributes: List[OpsResultAttributeTypeDef] = None,
         NextToken: str = None,
         MaxResults: int = None,
@@ -1237,7 +1237,7 @@ class SSMClient:
         self,
         InstanceId: str,
         TypeName: str,
-        Filters: List[InventoryFilterTypeDef] = None,
+        Filters: List["InventoryFilterTypeDef"] = None,
         NextToken: str = None,
         MaxResults: int = None,
     ) -> ListInventoryEntriesResultTypeDef:
@@ -1295,7 +1295,7 @@ class SSMClient:
         ResourceId: str,
         ResourceType: str,
         ComplianceType: str,
-        ExecutionSummary: ComplianceExecutionSummaryTypeDef,
+        ExecutionSummary: "ComplianceExecutionSummaryTypeDef",
         Items: List[ComplianceItemEntryTypeDef],
         ItemContentHash: str = None,
         UploadType: Literal["COMPLETE", "PARTIAL"] = None,
@@ -1320,7 +1320,7 @@ class SSMClient:
         KeyId: str = None,
         Overwrite: bool = None,
         AllowedPattern: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
         Tier: Literal["Standard", "Advanced", "Intelligent-Tiering"] = None,
         Policies: str = None,
         DataType: str = None,
@@ -1347,7 +1347,7 @@ class SSMClient:
         self,
         WindowId: str,
         ResourceType: Literal["INSTANCE", "RESOURCE_GROUP"],
-        Targets: List[TargetTypeDef],
+        Targets: List["TargetTypeDef"],
         OwnerInformation: str = None,
         Name: str = None,
         Description: str = None,
@@ -1360,16 +1360,16 @@ class SSMClient:
     def register_task_with_maintenance_window(
         self,
         WindowId: str,
-        Targets: List[TargetTypeDef],
+        Targets: List["TargetTypeDef"],
         TaskArn: str,
         TaskType: Literal["RUN_COMMAND", "AUTOMATION", "STEP_FUNCTIONS", "LAMBDA"],
         MaxConcurrency: str,
         MaxErrors: str,
         ServiceRoleArn: str = None,
-        TaskParameters: Dict[str, MaintenanceWindowTaskParameterValueExpressionTypeDef] = None,
-        TaskInvocationParameters: MaintenanceWindowTaskInvocationParametersTypeDef = None,
+        TaskParameters: Dict[str, "MaintenanceWindowTaskParameterValueExpressionTypeDef"] = None,
+        TaskInvocationParameters: "MaintenanceWindowTaskInvocationParametersTypeDef" = None,
         Priority: int = None,
-        LoggingInfo: LoggingInfoTypeDef = None,
+        LoggingInfo: "LoggingInfoTypeDef" = None,
         Name: str = None,
         Description: str = None,
         ClientToken: str = None,
@@ -1419,7 +1419,7 @@ class SSMClient:
         self,
         DocumentName: str,
         InstanceIds: List[str] = None,
-        Targets: List[TargetTypeDef] = None,
+        Targets: List["TargetTypeDef"] = None,
         DocumentVersion: str = None,
         DocumentHash: str = None,
         DocumentHashType: Literal["Sha256", "Sha1"] = None,
@@ -1432,8 +1432,8 @@ class SSMClient:
         MaxConcurrency: str = None,
         MaxErrors: str = None,
         ServiceRoleArn: str = None,
-        NotificationConfig: NotificationConfigTypeDef = None,
-        CloudWatchOutputConfig: CloudWatchOutputConfigTypeDef = None,
+        NotificationConfig: "NotificationConfigTypeDef" = None,
+        CloudWatchOutputConfig: "CloudWatchOutputConfigTypeDef" = None,
     ) -> SendCommandResultTypeDef:
         """
         [Client.send_command documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.send_command)
@@ -1452,12 +1452,12 @@ class SSMClient:
         ClientToken: str = None,
         Mode: Literal["Auto", "Interactive"] = None,
         TargetParameterName: str = None,
-        Targets: List[TargetTypeDef] = None,
+        Targets: List["TargetTypeDef"] = None,
         TargetMaps: List[Dict[str, List[str]]] = None,
         MaxConcurrency: str = None,
         MaxErrors: str = None,
-        TargetLocations: List[TargetLocationTypeDef] = None,
-        Tags: List[TagTypeDef] = None,
+        TargetLocations: List["TargetLocationTypeDef"] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> StartAutomationExecutionResultTypeDef:
         """
         [Client.start_automation_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.start_automation_execution)
@@ -1488,9 +1488,9 @@ class SSMClient:
         Parameters: Dict[str, List[str]] = None,
         DocumentVersion: str = None,
         ScheduleExpression: str = None,
-        OutputLocation: InstanceAssociationOutputLocationTypeDef = None,
+        OutputLocation: "InstanceAssociationOutputLocationTypeDef" = None,
         Name: str = None,
-        Targets: List[TargetTypeDef] = None,
+        Targets: List["TargetTypeDef"] = None,
         AssociationName: str = None,
         AssociationVersion: str = None,
         AutomationTargetParameterName: str = None,
@@ -1505,7 +1505,7 @@ class SSMClient:
         """
 
     def update_association_status(
-        self, Name: str, InstanceId: str, AssociationStatus: AssociationStatusTypeDef
+        self, Name: str, InstanceId: str, AssociationStatus: "AssociationStatusTypeDef"
     ) -> UpdateAssociationStatusResultTypeDef:
         """
         [Client.update_association_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/ssm.html#SSM.Client.update_association_status)
@@ -1555,7 +1555,7 @@ class SSMClient:
         self,
         WindowId: str,
         WindowTargetId: str,
-        Targets: List[TargetTypeDef] = None,
+        Targets: List["TargetTypeDef"] = None,
         OwnerInformation: str = None,
         Name: str = None,
         Description: str = None,
@@ -1569,15 +1569,15 @@ class SSMClient:
         self,
         WindowId: str,
         WindowTaskId: str,
-        Targets: List[TargetTypeDef] = None,
+        Targets: List["TargetTypeDef"] = None,
         TaskArn: str = None,
         ServiceRoleArn: str = None,
-        TaskParameters: Dict[str, MaintenanceWindowTaskParameterValueExpressionTypeDef] = None,
-        TaskInvocationParameters: MaintenanceWindowTaskInvocationParametersTypeDef = None,
+        TaskParameters: Dict[str, "MaintenanceWindowTaskParameterValueExpressionTypeDef"] = None,
+        TaskInvocationParameters: "MaintenanceWindowTaskInvocationParametersTypeDef" = None,
         Priority: int = None,
         MaxConcurrency: str = None,
         MaxErrors: str = None,
-        LoggingInfo: LoggingInfoTypeDef = None,
+        LoggingInfo: "LoggingInfoTypeDef" = None,
         Name: str = None,
         Description: str = None,
         Replace: bool = None,
@@ -1595,11 +1595,11 @@ class SSMClient:
         self,
         OpsItemId: str,
         Description: str = None,
-        OperationalData: Dict[str, OpsItemDataValueTypeDef] = None,
+        OperationalData: Dict[str, "OpsItemDataValueTypeDef"] = None,
         OperationalDataToDelete: List[str] = None,
-        Notifications: List[OpsItemNotificationTypeDef] = None,
+        Notifications: List["OpsItemNotificationTypeDef"] = None,
         Priority: int = None,
-        RelatedOpsItems: List[RelatedOpsItemTypeDef] = None,
+        RelatedOpsItems: List["RelatedOpsItemTypeDef"] = None,
         Status: Literal["Open", "InProgress", "Resolved"] = None,
         Title: str = None,
         Category: str = None,
@@ -1613,8 +1613,8 @@ class SSMClient:
         self,
         BaselineId: str,
         Name: str = None,
-        GlobalFilters: PatchFilterGroupTypeDef = None,
-        ApprovalRules: PatchRuleGroupTypeDef = None,
+        GlobalFilters: "PatchFilterGroupTypeDef" = None,
+        ApprovalRules: "PatchRuleGroupTypeDef" = None,
         ApprovedPatches: List[str] = None,
         ApprovedPatchesComplianceLevel: Literal[
             "CRITICAL", "HIGH", "MEDIUM", "LOW", "INFORMATIONAL", "UNSPECIFIED"
@@ -1623,7 +1623,7 @@ class SSMClient:
         RejectedPatches: List[str] = None,
         RejectedPatchesAction: Literal["ALLOW_AS_DEPENDENCY", "BLOCK"] = None,
         Description: str = None,
-        Sources: List[PatchSourceTypeDef] = None,
+        Sources: List["PatchSourceTypeDef"] = None,
         Replace: bool = None,
     ) -> UpdatePatchBaselineResultTypeDef:
         """
