@@ -9,7 +9,7 @@ Usage::
 """
 from datetime import datetime
 import sys
-from typing import Dict, IO, List, Union
+from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -1103,7 +1103,7 @@ MaintenanceWindowIdentityTypeDef = TypedDict(
 
 MaintenanceWindowLambdaParametersTypeDef = TypedDict(
     "MaintenanceWindowLambdaParametersTypeDef",
-    {"ClientContext": str, "Qualifier": str, "Payload": Union[bytes, IO]},
+    {"ClientContext": str, "Qualifier": str, "Payload": bytes},
     total=False,
 )
 
